/**
 * DISPLAY
 * The largest text on the screen is reserved for short, important text or numerals.
 */
export declare const displays: {
    xs: string;
    s: string;
    m: string;
    l: string;
};
export declare const lineDisplays: {
    xs: string;
    s: string;
    m: string;
    l: string;
};
export type TextDisplay = keyof typeof displays;
export type LineDisplay = keyof typeof lineDisplays;
/**
 * HEADING
 * Used to break up content into sections and provide a clear hierarchy of information.
 */
export declare const headings: {
    readonly xs: "1.25rem";
    readonly s: "1.5rem";
    readonly m: "1.75rem";
    readonly l: "2rem";
    readonly xl: "2.25rem";
    readonly xxl: "2.5rem";
};
export declare const lineHeadings: {
    readonly xs: "1.75rem";
    readonly s: "2rem";
    readonly m: "2.25rem";
    readonly l: "2.5rem";
    readonly xl: "2.75rem";
    readonly xxl: "3.25rem";
};
export type TextHeading = keyof typeof headings;
export type LineHeading = keyof typeof lineHeadings;
/**
 * LABEL
 *  A short phrase or sentence that provides context or information about a specific block of text.
 */
export declare const labels: {
    readonly xs: "0.75rem";
    readonly s: "0.875rem";
    readonly m: "1rem";
    readonly l: "1.125rem";
    readonly xl: "1.25rem";
    readonly xxl: "1.5rem";
};
export declare const lineLabels: {
    readonly xs: "1rem";
    readonly s: "1rem";
    readonly m: "1.25rem";
    readonly l: "1.5rem";
    readonly xl: "1.75rem";
    readonly xxl: "2.25rem";
};
export type TextLabel = keyof typeof labels;
export type LineLabel = keyof typeof lineLabels;
/**
 * PARAGRAPH
 * Longer blocks of text, used for mostly text-based content.
 */
export declare const paragraphs: {
    readonly xs: "0.75rem";
    readonly s: "0.875rem";
    readonly m: "1rem";
    readonly l: "1.125rem";
    readonly xl: "1.25rem";
};
export declare const lineParagraphs: {
    readonly xs: "1.25rem";
    readonly s: "1.25rem";
    readonly m: "1.5rem";
    readonly l: "1.75rem";
    readonly xl: "2.25rem";
};
export type TextParagraph = keyof typeof paragraphs;
export type LineParagraph = keyof typeof lineParagraphs;
export declare const fontWeight: {
    readonly thin: "100";
    readonly light: "200";
    readonly book: "300";
    readonly regular: "400";
    readonly medium: "500";
    readonly semibold: "600";
    readonly bold: "700";
    readonly xbold: "800";
    readonly xxbold: "900";
};
export type FontWeight = keyof typeof fontWeight;
